%global python3_pkgversion2 %(%{__python3} -c "import sys; sys.stdout.write(sys.version[:3].replace('.', ''))")
%if 0%{?fedora} || 0%{?rhel} >= 7
%global with_python2 0
%global with_python3 1
%global python3_pkgversion 3
%else
%global with_python2 1
%global with_python3 1
%global python3_pkgversion %{python3_pkgversion2}
%{!?python2_sitelib: %global python2_sitelib %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%endif

%define debug_package %{nil}

%define srcname oci
%define oci_version 2.56.0
%define rpmname oci-sdk

Name: python-oci-sdk
Version:        2.56.0
Release: 1%{?dist}
Url: http://pypi.python.org/pypi/%{srcname}
Summary: Oracle Cloud Infrastructure Python SDK
License: Apache2.0
Group: Development/Libraries
#Source: https://files.pythonhosted.org/packages/source/o/%%{srcname}/%%{srcname}-%%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%define cryptograph_version1 3.2.1
%define cryptograph_version2 3.4.7
%define dateutil_version 2.7.3
%define pyopenssl_version 19.1.0
%define click_version 7.1.2
%define six_version 1.15.0
%define configparser_version 4.0.2

SOURCE0: %{srcname}-%{version}.tar.bz2
SOURCE1: six-%{six_version}.tar.gz
SOURCE2: click-%{click_version}.tar.gz
SOURCE3: python-dateutil-%{dateutil_version}.tar.gz
SOURCE4: pyOpenSSL-%{pyopenssl_version}.tar.gz
PATCH0:  LICENSE.txt.patch

#BuildArch: noarch

%global _description\
Python SDK for Oracle Cloud Infrastructure.


%if %{with_python2}
#%%package -n python2-%%{rpmname}
#Summary: %%summary

BuildRequires: python2-devel
BuildRequires: python-setuptools >= 24.3
BuildRequires: openssl-devel 

#required by SDK  
#  embedded in SDK
#        "idna = 2.10",
#        "six = 1.15.0",
#        "requests = 2.25.1",
#        "urllib3 = 1.24.1"
#        "chardet = 4.0.0"
#        "httpsig_cffi"
#        "jwt = 1.7.1"

Requires: python-certifi >= 2017.4.17
Requires: python-configparser == %{configparser_version}
Requires: pytz	>= 2016.10
Requires: python-cryptography >= %{cryptograph_version1}
Requires: python-cryptography <= %{cryptograph_version2}
Requires: python%{python3_pkgversion}-circuitbreaker >= 1.3.1
Requires: python%{python3_pkgversion}-circuitbreaker < 2

# bundled deps: six, dateutils, pyOpenSSL

# Required by dateutil
BuildRequires: python2-setuptools_scm

provides: python2-%{rpmname} = %{version}-%{release}
%endif 

%description %_description

%if %{with_python3}
%package -n python%{python3_pkgversion2}-%{rpmname}
Summary: %summary

BuildRequires: python%{python3_pkgversion}-devel
BuildRequires: python%{python3_pkgversion}-setuptools >= 24.3
BuildRequires: openssl-devel 

#required by SDK  
Requires: python%{python3_pkgversion}-certifi >= 2017.4.17
Requires: python%{python3_pkgversion}-pytz	>= 2016.10
Requires: python%{python3_pkgversion}-cryptography >= %{cryptograph_version1}
Requires: python%{python3_pkgversion}-cryptography <= %{cryptograph_version2}
Requires: python%{python3_pkgversion}-circuitbreaker >= 1.3.1
Requires: python%{python3_pkgversion}-circuitbreaker < 2
#Required by six bundled:
# Required by dateutil
BuildRequires: python%{python3_pkgversion}-setuptools_scm

provides: python3-%{rpmname} = %{version}-%{release}

%description -n python%{python3_pkgversion2}-%{rpmname} %_description
%endif

%prep
%setup -q -n %{srcname}-%{version}
%patch0 -p1 

patchfile=%{_builddir}/%{srcname}-%{version}/src/oci/__init__.py
sed 4i"import os, sys" -i $patchfile
sed 5i"sys.path.insert(0,(os.path.join(os.path.dirname(__file__),'packages')))" -i $patchfile
sed 5i"sys.path.insert(0,(os.path.join(os.path.dirname(__file__),'_vendor')))" -i $patchfile

mkdir -p packages
tar -zxvf %SOURCE1 --directory=packages
tar -zxvf %SOURCE2 --directory=packages
tar -zxvf %SOURCE3 --directory=packages
tar -zxvf %SOURCE4 --directory=packages

%build
bundled="six click python-dateutil pyOpenSSL"
%if %{with_python2}
%{__python2} setup.py build
mkdir -p site2_packages
for pkg in $bundled; do
pushd packages/${pkg}*
%{__python2} setup.py install -O1 --prefix=%{_prefix} --root=../../site2_packages
popd
done
%endif # with_python2
%if %{with_python3}
%{__python3} setup.py build
mkdir -p site3_packages
for pkg in $bundled; do
pushd packages/${pkg}*
%{__python3} setup.py install -O1 --prefix=%{_prefix} --root=../../site3_packages
popd
done
%endif # with_python3

for pkg in $bundled; do
pushd packages/${pkg}*
licenseDir=${PWD/packages/package_licenses}
mkdir -p $licenseDir
cp LICENSE* $licenseDir
popd
done



%install
%if %{with_python2}
%{__python2} setup.py install -O1 --prefix=%{_prefix} --root=%{buildroot}
install -d %{buildroot}%{python2_sitelib}/oci/packages  
mv  %{_builddir}/%{srcname}-%{version}/site2_packages/usr/*/*/site-packages/* %{buildroot}%{python2_sitelib}/oci/packages
%endif # with_python2

%if %{with_python3}
cd %{_builddir}/%{srcname}-%{version}
%{__python3} setup.py install -O1 --prefix=%{_prefix} --root=%{buildroot}
install -d %{buildroot}%{python3_sitelib}/oci/packages  
mv %{_builddir}/%{srcname}-%{version}/site3_packages/usr/*/*/site-packages/* %{buildroot}%{python3_sitelib}/oci/packages
%endif # with_python3

# Change the shebang to a versioned Python executable
%if %{with_python2}
sed -i "1s:^#!/usr/bin/env python$:#!%{__python2}:" \
    %{buildroot}%{python2_sitelib}/*/*.py* 
%endif

%if %{with_python3}
sed -i "1s:^#!/usr/bin/env python$:#!%{__python3}:" \
    %{buildroot}%{python3_sitelib}/*/*.py*
%endif

%clean
rm -rf %{buildroot}

%if %{with_python2}
%files 
%defattr(-,root,root)
%{python2_sitelib}/oci*
%doc README.rst LICENSE.txt THIRD_PARTY_LICENSES.txt CHANGELOG.rst CONTRIBUTING.rst examples/ docs/
%doc package_licenses/
%endif # with_python2

%if %{with_python3}
%files -n  python%{python3_pkgversion2}-%{rpmname}
%defattr(-,root,root)
%{python3_sitelib}/oci*
%doc README.rst LICENSE.txt THIRD_PARTY_LICENSES.txt CHANGELOG.rst CONTRIBUTING.rst examples/ docs/
%doc package_licenses/
%endif # with_python3

%changelog
* Tue Feb 08 2022 EL Errata <el-errata_ww@oracle.com> 2.56.0-1
- Update to version 2.56.0

* Tue Feb 01 2022 EL Errata <el-errata_ww@oracle.com> 2.55.1-1
- Update to version 2.55.1

* Tue Jan 25 2022 EL Errata <el-errata_ww@oracle.com> 2.55.0-1
- Update to version 2.55.0

* Tue Jan 18 2022 EL Errata <el-errata_ww@oracle.com> 2.54.1-1
- Update to version 2.54.1

* Tue Jan 11 2022 EL Errata <el-errata_ww@oracle.com> 2.54.0-1
- Update to version 2.54.0

* Tue Dec 21 2021 EL Errata <el-errata_ww@oracle.com> 2.53.1-1
- Update to version 2.53.1

* Tue Dec 14 2021 EL Errata <el-errata_ww@oracle.com> 2.53.0-1
- Update to version 2.53.0

* Tue Dec 07 2021 EL Errata <el-errata_ww@oracle.com> 2.52.1-1
- Update to version 2.52.1

* Tue Nov 30 2021 EL Errata <el-errata_ww@oracle.com> 2.52.0-1
- Update to version 2.52.0

* Wed Nov 17 2021 EL Errata <el-errata_ww@oracle.com> 2.51.0-1
- Update to version 2.51.0

* Tue Nov 09 2021 EL Errata <el-errata_ww@oracle.com> 2.50.0-1
- Update to version 2.50.0

* Tue Nov 02 2021 EL Errata <el-errata_ww@oracle.com> 2.49.1-1
- Update to version 2.49.1

* Tue Oct 26 2021 EL Errata <el-errata_ww@oracle.com> 2.49.0-1
- Update to version 2.49.0

* Tue Oct 19 2021 EL Errata <el-errata_ww@oracle.com> 2.48.0-1
- Update to version 2.48.0

* Tue Oct 12 2021 EL Errata <el-errata_ww@oracle.com> 2.47.1-1
- Update to version 2.47.1

* Tue Oct 05 2021 EL Errata <el-errata_ww@oracle.com> 2.47.0-1
- Update to version 2.47.0

* Tue Sep 28 2021 EL Errata <el-errata_ww@oracle.com> 2.46.0-1
- Update to version 2.46.0

* Tue Sep 14 2021 EL Errata <el-errata_ww@oracle.com> 2.45.1-1
- Update to version 2.45.1

* Tue Sep 07 2021 EL Errata <el-errata_ww@oracle.com> 2.45.0-1
- Update to version 2.45.0

* Tue Aug 31 2021 EL Errata <el-errata_ww@oracle.com> 2.44.2-1
- Update to version 2.44.2

* Tue Aug 24 2021 EL Errata <el-errata_ww@oracle.com> 2.44.1-1
- Update to version 2.44.1

* Tue Aug 17 2021 EL Errata <el-errata_ww@oracle.com> 2.44.0-1
- Update to version 2.44.0
- Update dependency six to 1.15.0

* Tue Aug 03 2021 EL Errata <el-errata_ww@oracle.com> 2.43.2-1
- Update to version 2.43.2

* Tue Jul 27 2021 EL Errata <el-errata_ww@oracle.com> 2.43.1-1
- Update to version 2.43.1

* Tue Jul 20 2021 EL Errata <el-errata_ww@oracle.com> 2.43.0-1
- Update to version 2.43.0

* Tue Jul 13 2021 EL Errata <el-errata_ww@oracle.com> 2.42.0-1
- Update to version 2.42.0

* Tue Jul 06 2021 EL Errata <el-errata_ww@oracle.com> 2.41.1-1
- Update to version 2.41.1

* Tue Jun 29 2021 EL Errata <el-errata_ww@oracle.com> 2.41.0-1
- Update to version 2.41.0

* Tue Jun 22 2021 Qing Lin <qing.lin@oracle.com> 2.40.1-1
- Update to version 2.40.1
- Change cryptography version to a range
- Use standalone cryptography instead of embedding in the package

* Tue Jun 15 2021 EL Errata <el-errata_ww@oracle.com> 2.40.0-1
- Update to version 2.40.0

* Tue Jun 08 2021 EL Errata <el-errata_ww@oracle.com> 2.39.1-1
- Update to version 2.39.1

* Tue Jun 01 2021 EL Errata <el-errata_ww@oracle.com> 2.39.0-1
- Update to version 2.39.0

* Tue May 25 2021 EL Errata <el-errata_ww@oracle.com> 2.38.4-1
- Update to version 2.38.4

* Tue May 18 2021 EL Errata <el-errata_ww@oracle.com> 2.38.3-1
- Update to version 2.38.3

* Tue May 11 2021 EL Errata <el-errata_ww@oracle.com> 2.38.2-1
- Update to version 2.38.2

* Tue May 04 2021 EL Errata <el-errata_ww@oracle.com> 2.38.1-1
- Update to version 2.38.1

* Tue Apr 27 2021 EL Errata <el-errata_ww@oracle.com> 2.38.0-1
- Update to version 2.38.0

* Tue Apr 20 2021 EL Errata <el-errata_ww@oracle.com> 2.37.0-1
- Update to version 2.37.0

* Tue Apr 13 2021 EL Errata <el-errata_ww@oracle.com> 2.36.0-1
- Update to version 2.36.0

* Tue Apr 06 2021 EL Errata <el-errata_ww@oracle.com> 2.35.1-1
- Update to version 2.35.1

* Tue Mar 30 2021 EL Errata <el-errata_ww@oracle.com> 2.35.0-1
- Update to version 2.35.0

* Tue Mar 23 2021 EL Errata <el-errata_ww@oracle.com> 2.34.0-1
- Update to version 2.34.0

* Tue Mar 16 2021 EL Errata <el-errata_ww@oracle.com> 2.33.0-1
- Update to version 2.33.0

* Tue Mar 09 2021 EL Errata <el-errata_ww@oracle.com> 2.32.1-1
- Update to version 2.32.1

* Tue Mar 02 2021 EL Errata <el-errata_ww@oracle.com> 2.32.0-1
- Update to version 2.32.0

* Tue Feb 23 2021 EL Errata <el-errata_ww@oracle.com> 2.31.2-1
- Update to version 2.31.2

* Tue Feb 16 2021 EL Errata <el-errata_ww@oracle.com> 2.31.1-1
- Update to version 2.31.1

* Tue Feb 09 2021 EL Errata <el-errata_ww@oracle.com> 2.31.0-1
- Update to version 2.31.0

* Tue Feb 02 2021 EL Errata <el-errata_ww@oracle.com> 2.30.0-1
- Update to version 2.30.0

* Tue Jan 26 2021 EL Errata <el-errata_ww@oracle.com> 2.29.0-1
- Update to version 2.29.0

* Tue Jan 19 2021 EL Errata <el-errata_ww@oracle.com> 2.28.0-1
- Update to version 2.28.0

* Tue Jan 12 2021 EL Errata <el-errata_ww@oracle.com> 2.27.0-1
- Update to version 2.27.0

* Tue Dec 15 2020 EL Errata <el-errata_ww@oracle.com> 2.26.0-1
- Update to version 2.26.0

* Wed Dec 09 2020 Qing Lin <el-errata_ww@oracle.com> 2.25.1-1
- Update dependency cryptography and pyOpenSSL.

* Tue Dec 08 2020 EL Errata <el-errata_ww@oracle.com> 2.25.1-1
- Update to version 2.25.1

* Tue Dec 01 2020 EL Errata <el-errata_ww@oracle.com> 2.25.0-1
- Update to version 2.25.0

* Tue Nov 17 2020 EL Errata <el-errata_ww@oracle.com> 2.24.0-1
- Update to version 2.24.0

* Tue Nov 10 2020 EL Errata <el-errata_ww@oracle.com> 2.23.5-1
- Update to version 2.23.5

* Fri Oct 30 2020 EL Errata <el-errata_ww@oracle.com> 2.23.3-1
- Update to version 2.23.3

* Tue Oct 27 2020 EL Errata <el-errata_ww@oracle.com> 2.23.2-1
- Update to version 2.23.2

* Tue Oct 20 2020 EL Errata <el-errata_ww@oracle.com> 2.23.1-1
- Update to version 2.23.1

* Tue Oct 13 2020 EL Errata <el-errata_ww@oracle.com> 2.23.0-1
- Update to version 2.23.0

* Tue Oct 06 2020 EL Errata <el-errata_ww@oracle.com> 2.22.0-1
- Update to version 2.22.0

* Tue Sep 29 2020 EL Errata <el-errata_ww@oracle.com> 2.21.6-1
- Update to version 2.21.6

* Tue Sep 22 2020 EL Errata <el-errata_ww@oracle.com> 2.21.5-1
- Update to version 2.21.5

* Tue Sep 15 2020 EL Errata <el-errata_ww@oracle.com> 2.21.4-1
- Update to version 2.21.4

* Tue Sep 08 2020 EL Errata <el-errata_ww@oracle.com> 2.21.3-1
- Update to version 2.21.3

* Tue Aug 18 2020 Qing Lin <el-errata_ww@oracle.com> 2.21.1-1
- Update to version 2.21.1

* Wed Aug 12 2020 Qing Lin <el-errata_ww@oracle.com> 2.21.0-1.0.1
- Fix the conflict issue during "yum update"  [Orabug: 31747983]
- Include the Licenses of the embedded packages.
- Update the required dependencies based on the source code change

* Tue Aug 11 2020 EL Errata <el-errata_ww@oracle.com> 2.21.0-1
- Update to version 2.21.0

* Tue Aug 04 2020 EL Errata <el-errata_ww@oracle.com> 2.20.0-1
- Update to version 2.20.0

* Tue Jul 28 2020 EL Errata <el-errata_ww@oracle.com> 2.19.0-1
- Update to version 2.19.0

* Tue Jul 21 2020 EL Errata <el-errata_ww@oracle.com> 2.18.1-1
- Update to version 2.18.1

* Tue Jul 14 2020 EL Errata <el-errata_ww@oracle.com> 2.18.0-1
- Update to version 2.18.0

* Tue Jul 07 2020 EL Errata <el-errata_ww@oracle.com> 2.17.2-1
- Update to version 2.17.2

* Tue Jun 30 2020 EL Errata <el-errata_ww@oracle.com> 2.17.1-1
- Update to version 2.17.1

* Tue Jun 23 2020 EL Errata <el-errata_ww@oracle.com> 2.17.0-1
- Update to version 2.17.0

* Tue Jun 16 2020 EL Errata <el-errata_ww@oracle.com> 2.16.1-1
- Update to version 2.16.1

* Tue Jun 09 2020 EL Errata <el-errata_ww@oracle.com> 2.16.0-1
- Update to version 2.16.0

* Thu Jun 04 2020 Qing Lin <qing.lin@oracle.com> 2.15.0-1.0.1
- Added docs and examples to the package [Orabug: 31449070]

* Tue Jun 02 2020 EL Errata <el-errata_ww@oracle.com> 2.15.0-1
- Update to version 2.15.0

* Tue May 19 2020 EL Errata <el-errata_ww@oracle.com> 2.14.3-1
- Update to version 2.14.3

* Tue May 12 2020 EL Errata <el-errata_ww@oracle.com> 2.14.2-1
- Update to version 2.14.2

* Tue May 05 2020 EL Errata <el-errata_ww@oracle.com> 2.14.1-1
- Update to version 2.14.1

* Tue Apr 28 2020 EL Errata <el-errata_ww@oracle.com> 2.14.0-1
- Update to version 2.14.0

* Tue Apr 21 2020 EL Errata <el-errata_ww@oracle.com> 2.13.0-1
- Update to version 2.13.0

* Tue Apr 14 2020 EL Errata <el-errata_ww@oracle.com> 2.12.4-1
- Update to version 2.12.4

* Thu Apr 09 2020 EL Errata <el-errata_ww@oracle.com> 2.12.3-1
- Update to version 2.12.3

* Tue Mar 31 2020 EL Errata <el-errata_ww@oracle.com> 2.12.2-1
- Update to version 2.12.2

* Tue Mar 24 2020 EL Errata <el-errata_ww@oracle.com> 2.12.1-1
- Update to version 2.12.1

* Tue Mar 17 2020 Qing Lin <qing.lin@oracle.com> 2.12.0-1
- Update to version 2.12.0
- Remove unused dependencies.
- Add idna requirement to avoid dependency conflict with CLI.

* Tue Mar 10 2020 EL Errata <el-errata_ww@oracle.com> 2.11.0-1
- Update to version 2.11.0

* Tue Mar 10 2020 Qing Lin <qing.lin@oracle.com> 2.10.7-1.0.2
- Added missing entries in changelog.  [Orabug: 30989862]
- Changed python36-pyOpenSSL version to 17.5.  [Orabug: 31012037]
	
* Wed Mar 04 2020 Qing Lin <qing.lin@oracle.com> 2.10.7-1.0.1
- Update dependency six to 1.14.0
	
* Tue Mar 03 2020 EL Errata <el-errata_ww@oracle.com> 2.10.7-1
- Update to version 2.10.7

* Tue Feb 25 2020 EL Errata <el-errata_ww@oracle.com> 2.10.6-1
- Update to version 2.10.6

* Tue Feb 18 2020 EL Errata <el-errata_ww@oracle.com> 2.10.5-1
- Update to version 2.10.5

* Wed Feb 12 2020 John Mcwalters <john.mcwalters@oracle.com> 2.10.4-1
- Update to version 2.10.4

* Wed Feb 05 2020 Qing Lin <qing.lin@oracle.com> 2.10.3-1.0.1
- added build for python3 

* Tue Feb 04 2020 EL Errata <el-errata_ww@oracle.com> 2.10.2-1
- Update to version 2.10.2

* Tue Jan 28 2020 EL Errata <el-errata_ww@oracle.com> 2.10.2-1
- Update to version 2.10.2

* Tue Jan 21 2020 EL Errata <el-errata_ww@oracle.com> 2.10.1-1
- Update to version 2.10.1

* Wed Jan 15 2020 Tianyue Lan <tianyue.lan@oracle.com> 2.10.0-2
- Upgrade to cryptography-2.8.tar.gz

* Tue Jan 14 2020 Jingdong Lu <jingdong.lu@oracle.com> 2.10.0-1
- Update to version 2.10.0

* Wed Jan 08 2020 Jingdong Lu <jingdong.lu@oracle.com> 2.9.0-1
- Update to version 2.9.0

* Wed Dec 18 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.8.0-1
- Update to version 2.8.0

* Tue Dec 10 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.7.1-1
- Update to version 2.7.1

* Tue Nov 26 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.7.0-1
- Update to version 2.7.0
 
* Tue Nov 19 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.6.5-1
- Update to version 2.6.5

* Wed Nov 13 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.6.4-1
- Update to version 2.6.4

* Tue Nov 05 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.6.3-1
- Update to version 2.6.3

* Tue Oct 29 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.6.2-1
- Update to version 2.6.2

* Tue Oct 15 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.6.1-1
- Update to version 2.6.1

* Tue Oct 08 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.6.0-1
- Update to version 2.6.0

* Tue Oct 01 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.5.2-1
- Update to version 2.5.2

* Tue Sep 24 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.5.1-1
- Update to version 2.5.1

* Tue Sep 17 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.5.0-1
- Update to version 2.5.0

* Tue Sep 10 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.4.0-1
- Update to version 2.4.0

* Tue Sep 03 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.3.3-1
- Update to version 2.3.3

* Tue Aug 27 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.3.2-1
- Update to version 2.3.2

* Tue Aug 20 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.3.1-1
- Update to version 2.3.1

* Tue Aug 13 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.3.0-1
- Update to version 2.3.0

* Tue Aug 06 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.21-1
- Update to version 2.2.21

* Tue Jul 30 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.20-1
- Update to version 2.2.20

* Tue Jul 23 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.19-1
- Update to version 2.2.19

* Tue Jul 16 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.18-1
- Update to version 2.2.18

* Tue Jul 09 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.17-1
- Update to version 2.2.17

* Tue Jul 02 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.16-1
- Update to version 2.2.16

* Tue Jun 25 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.15-1
- Update to version 2.2.15

* Tue Jun 18 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.14-1
- Update to version 2.2.14

* Tue Jun 11 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.13-1
- Update to version 2.2.13

* Tue Jun 04 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.12-1
- Update to version 2.2.12

* Tue May 28 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.11-1
- Update to version 2.2.11

* Tue May 21 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.10-1
- Update to version 2.2.10

* Tue May 14 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.9-1
- Update to version 2.2.9

* Tue Apr 16 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.7-1
- Update to version 2.2.7

* Tue Apr 09 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.6-1
- Update to version 2.2.6

* Tue Apr 02 2019 Alan Steinberg <alan.steinberg@oracle.com> 2.2.5-1
- Update to version 2.2.5
- Modified description and summary to be Oracle Cloud Infrastructure.

* Tue Mar 26 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.4-1
- Update to version 2.2.4

* Tue Mar 19 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.3-1
- Update to version 2.2.3

* Tue Mar 12 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.2-1
- Update to version 2.2.2

* Thu Feb 28 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.1-1
- Update to version 2.2.1

* Thu Feb 21 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.2.0-1
- Update to version 2.2.0

* Thu Feb 07 2019 John Mcwalters <john.mcwalters@oracle.com> 2.1.7-1
- Update to version 2.1.7

* Thu Jan 31 2019 John Mcwalters <john.mcwalters@oracle.com> 2.1.6-1.0.1
- Upgrade to cryptography-2.4.2.tar.gz

* Thu Jan 31 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.1.6-1
- Update to version 2.1.6

* Thu Jan 31 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.1.5-2
- Upgrade to cryptography-2.4.2.tar.gz

* Thu Jan 24 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.1.5-1
- Update to version 2.1.5

* Mon Jan 14 2019 Jingdong Lu <jingdong.lu@oracle.com> 2.1.4-1
- Update to version 2.1.4

* Fri Dec 21 2018 Qing Lin <qing.lin@oracle.com> 2.1.3-1.0.1
- Upgrade to cryptography-2.1.4

* Thu Dec 13 2018 Jingdong Lu <jingdong.lu@oracle.com> 2.1.3-1
- Update to version 2.1.3

* Thu Nov 29 2018 Jingdong Lu <jingdong.lu@oracle.com> 2.1.2-1
- Update to version 2.1.2

* Thu Nov 15 2018 Jingdong Lu <jingdong.lu@oracle.com> 2.1.1-1
- Update to version 2.1.1

* Thu Nov 01 2018 Jingdong Lu <jingdong.lu@oracle.com> 2.1.0-1
- Update to version 2.1.0

* Thu Oct 04 2018 Jingdong Lu <jingdong.lu@oracle.com> 2.0.5-1
- Update to version 2.0.5

* Thu Sep 27 2018 Jingdong Lu <jingdong.lu@oracle.com> 2.0.4-1
- Update to version 2.0.4

* Thu Sep 06 2018 Jingdong Lu <jingdong.lu@oracle.com> 2.0.3-1
- Update to version 2.0.3

* Thu Aug 23 2018 Jingdong Lu <jingdong.lu@oracle.com> 2.0.2-1
- Update to version 2.0.2

* Thu Aug 09 2018 Jingdong Lu <jingdong.lu@oracle.com> 2.0.1-1
- Update to version 2.0.1

* Thu Jul 26 2018 Jingdong Lu <jingdong.lu@oracle.com> 2.0.0-1
- Update to version 2.0.0

* Thu Jul 12 2018 Jingdong Lu <jingdong.lu@oracle.com> 1.4.5-1
- Update to version 1.4.5

* Fri Jun 29 2018 Jingdong Lu <jingdong.lu@oracle.com> 1.4.4-1
- Update to version 1.4.4

* Thu Jun 14 2018 Jingdong Lu <jingdong.lu@oracle.com> 1.4.3-1
- Update to version 1.4.3

* Mon Jun 04 2018 Qing Lin <qing.lin@oracle.com> 1.4.1-2
- Fixed the dependency change issue.

* Thu May 31 2018 Jingdong Lu <jingdong.lu@oracle.com> 1.4.1-1
- Update to version 1.4.1

* Thu May 17 2018 Jingdong Lu <jingdong.lu@oracle.com> 1.4.0-1
- Update to version 1.4.0

* Thu May 03 2018 Jingdong Lu <jingdong.lu@oracle.com> 1.3.20-1
- Update to version 1.3.20

* Thu Apr 19 2018 Jingdong Lu <jingdong.lu@oracle.com> 1.3.19-1
- Update to version 1.3.19

* Wed Apr 18 2018 Qing Lin <qing.lin@oracle.com> -1.3.18-2
- Updated the requirement versions same as the package requirement.

* Fri Apr 06 2018 Jingdong Lu <jingdong.lu@oracle.com> 1.3.18-1
- Update to version 1.3.18

* Mon Mar 26 2018 Jingdong Lu <jingdong.lu@oracle.com> 1.3.17-1
- Update to version 1.3.17

* Thu Mar 08 2018 Jingdong Lu <jingdong.lu@oracle.com> 1.3.16-1
- Update to version 1.3.16

* Thu Feb 22 2018 Jingdong Lu <jingdong.lu@oracle.com> - 1.3.15-1
- Update to version 1.3.15

* Fri Feb 09 2018 Qing Lin <qing.lin@oracle.com> -1.3.14-1
- Updated to version 1.3.14

* Tue Jan 23 2018 Qing Lin <qing.lin@oracle.com> -1.3.12-3
- Updated the requirement versions based on requests package.

* Mon Jan 22 2018 Qing Lin <qing.lin@oracle.com> -1.3.12-2
- Add changelog and requires for urllib3.

* Fri Jan 19 2018 Qing Lin <qing.lin@oracle.com> -1.3.12-1
- update for  spec file for oci 1.3.12

* Fri Sep 15 2017 Qing Lin <qing.lin@oracle.com>
- update for  spec file for oci 1.3.7

* Wed May 31 2017 Laszlo (Laca) Peter <laszlo.peter@oracle.com>
- initial spec file for oci 1.3.2
